Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(51)

Unified Diff: chrome/installer/util/product_operations.h

Issue 7005019: Put SxS switches back into the rename command. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/installer/util/product.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/util/product_operations.h
===================================================================
--- chrome/installer/util/product_operations.h (revision 84779)
+++ chrome/installer/util/product_operations.h (working copy)
@@ -51,11 +51,14 @@
virtual void AddComDllList(const std::set<std::wstring>& options,
std::vector<FilePath>* com_dll_list) const = 0;
- // Given a command line, appends the set of uninstall flags the uninstaller
- // for this product will require.
- virtual void AppendProductFlags(const std::set<std::wstring>& options,
- CommandLine* uninstall_command) const = 0;
+ // Given a command line, appends the set of product-specific uninstall flags.
+ virtual void AppendUninstallFlags(const std::set<std::wstring>& options,
+ CommandLine* cmd_line) const = 0;
+ // Given a command line, appends the set of product-specific rename flags.
+ virtual void AppendRenameFlags(const std::set<std::wstring>& options,
+ CommandLine* cmd_line) const = 0;
+
// Adds or removes product-specific flags in |channel_info|. Returns true if
// |channel_info| is modified.
virtual bool SetChannelFlags(const std::set<std::wstring>& options,
« no previous file with comments | « chrome/installer/util/product.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698